==> nextcloud-31.0.8-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/theming/l10n/sv.js <==
OC.L10N.register(
    "theming",
    {
    "The given name is too long" : "Det angivna namnet är för långt",
    "The given web address is too long" : "Den angivna adressen är för lång",
    "The given web address is not a valid URL" : "Den angivna webbadressen är inte en giltig webbadress",
    "The given legal notice address is too long" : "Den angivna juridiska notisadressen är för lång",
    "The given legal notice address is not a valid URL" : "Den angivna juridiska notisadressen är inte en giltig webbadress",
    "The given privacy policy address is too long" : "Den angivna sekretesspolicyadressen är för lång",
    "The given privacy policy address is not a valid URL" : "Den angivna sekretesspolicyadressen är inte en giltig webbadress",
    "The given slogan is too long" : "Den angivna slogan är för lång",
    "The given color is invalid" : "Den angivna färgen är inte tillgänglig",
    "Disable-user-theming should be true or false" : "Inaktivera teman för användare ska vara sant eller falskt",
    "Saved" : "Sparat",
    "Invalid app given" : "Ogiltig app angiven",
    "Invalid type for setting \"defaultApp\" given" : "Ogiltig typ för inställning av \"defaultApp\" angiven",
    "Invalid setting key" : "Ogiltig inställningsnyckel",
    "The file was uploaded" : "Filen laddades upp",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "Uppladdningsfilen är för stor (upload_max_filesize i php.ini)",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Den uppladdade filen överstiger MAX_FILE_SIZE-instruktionen specificerad i HTML-form",
    "The file was only partially uploaded" : "Filen var endast delvis uppladdad",
    "No file was uploaded" : "Ingen fil laddades upp",
    "Missing a temporary folder" : "Saknar en temporär mapp",
    "Could not write file to disk" : "Kunde inte skriva fil till disk",
    "A PHP extension stopped the file upload" : "Ett PHP-tillägg stoppade filuppladdning",
    "No file uploaded" : "Ingen fil uppladdad",
    "You are already using a custom theme. Theming app settings might be overwritten by that." : "Du använder redan ett anpassat tema. Dessa appinställningar kan skrivas över.",
    "Theming" : "Teman",
    "Appearance and accessibility" : "Utseende och tillgänglighet",
    "Dark theme with high contrast mode" : "Mörkt tema med högkontrastläge",
    "Enable dark high contrast mode" : "Aktivera mörkt högkontrastläge",
    "Similar to the high contrast mode, but with dark colours." : "Liknar högkontrastläget, men med mörka färger.",
    "Dark theme" : "Mörkt tema",
    "Enable dark theme" : "Aktivera mörkt tema",
    "A dark theme to ease your eyes by reducing the overall luminosity and brightness." : "Ett mörkt tema som underlättar för dina ögon genom att minska den totala ljusstyrkan.",
    "System default theme" : "Systemets standardtema",
    "Enable the system default" : "Aktivera systemets standard",
    "Using the default system appearance." : "Använder systemets standardutseende.",
    "Dyslexia font" : "Teckensnitt för dyslektiker",
    "Enable dyslexia font" : "Aktivera teckensnitt för dyslektiker",
    "OpenDyslexic is a free typeface/font designed to mitigate some of the common reading errors caused by dyslexia." : "OpenDyslexic är ett fritt teckensnitt/font som är utformat för att mildra några av de vanligaste lässvårigheterna som orsakas av dyslexi.",
    "High contrast mode" : "Läge med hög kontrast",
    "Enable high contrast mode" : "Aktivera läge med hög kontrast",
    "A high contrast mode to ease your navigation. Visual quality will be reduced but clarity will be increased." : "Ett läge med hög kontrast för att underlätta din navigering. Visuell kvalitet kommer att minska men tydligheten ökar.",
    "Light theme" : "Ljust tema",
    "Enable the default light theme" : "Aktivera ljust standardtema",
    "The default light appearance." : "Standardutseende för ljust tema.",
    "Legal notice" : "Rättsligt meddelande",
    "Privacy policy" : "Integritetspolicy",
    "Adjust the Nextcloud theme" : "Justera Nextcloud-tema",
    "Name" : "Namn",
    "Web link" : "Webblänk",
    "a safe home for all your data" : "ett säkert hem för all din data",
    "Slogan" : "Slogan",
    "Primary color" : "Primär färg",
    "Legal notice link" : "Länk rättsligt meddelande",
    "Privacy policy link" : "Länk integritetspolicy",
    "Header logo" : "Huvud-logga",
    "Upload new header logo" : "Ladda upp ny huvud-logga",
    "Favicon" : "Favicon",
    "Upload new favicon" : "Ladda upp nya favicon",
    "User settings" : "Användarinställningar",
    "Disable user theming" : "Inaktivera teman för användare",
    "Although you can select and customize your instance, users can change their background and colors. If you want to enforce your customization, you can toggle this on." : "Även om du kan välja och anpassa din instans kan användare ändra sin bakgrund och färger. Om du vill genomdriva din anpassning kan du aktivera detta.",
    "Theming makes it possible to easily customize the look and feel of your instance and supported clients. This will be visible for all users." : "Teman gör det möjligt att enkelt skräddarsy utseendet på ditt moln. Detta kommer att synas för alla användare.",
    "Background color" : "Bakgrundsfärg",
    "Upload new logo" : "Ladda upp ny logotyp",
    "Logo" : "Logotyp",
    "Upload new background and login image" : "Ladda upp ny bakgrund och inloggningsbild",
    "Background and login image" : "Bakgrund och inloggningsbild",
    "Advanced options" : "Avancerade inställningar",
    "Install the ImageMagick PHP extension with support for SVG images to automatically generate favicons based on the uploaded logo and color." : "Installera Imagemagick PHP-tillägget med stöd för SVG-bilder för att automatiskt generera favicons baserat på den uppladdade logotypen och färgen.",
    "If you find any issues, do not hesitate to report them on {issuetracker}our issue tracker{linkend}. And if you want to get involved, come join {designteam}our design team{linkend}!" : "Om du hittar några problem, tveka inte att rapportera dem på {issuetracker}vår problemhanterare{linkend}. Och om du vill engagera dig, gå med i {designteam}vårt designteam{linkend}!",
    "Appearance and accessibility settings" : "Utseende och tillgänglighetsinställningar",
    "Misc accessibility options" : "Diverse tillgänglighetsalternativ",
    "Customization has been disabled by your administrator" : "Anpassning har inaktiverats av din administratör",
    "Background and color" : "Bakgrund och färg",
    "Keyboard shortcuts" : "Tangentbordsgenvägar",
    "In some cases keyboard shortcuts can interfere with accessibility tools. In order to allow focusing on your tool correctly you can disable all keyboard shortcuts here. This will also disable all available shortcuts in apps." : "I vissa fall kan tangentbordsgenvägar störa tillgänglighetsverktyg. För att kunna fokusera på ditt verktyg korrekt kan du inaktivera alla tangentbordsgenvägar här. Detta kommer också att inaktivera alla tillgängliga genvägar i appar.",
    "Disable all keyboard shortcuts" : "Inaktivera alla tangentbordsgenvägar",
    "Current selected app: {app}, position {position} of {total}" : "Aktuell vald app: {app}, position {position} av {total}",
    "Move up" : "Flytta upp",
    "Move down" : "Flytta ner",
    "Select a background from your files" : "Välj en bakgrund från dina filer",
    "Select background" : "Välj bakgrund",
    "No background has been selected" : "Ingen bakgrund har valts",
    "Custom background" : "Anpassad bakgrund",
    "Plain background" : "Enkel bakgrund",
    "Default background" : "Standardbakgrund",
    "Theme selection is enforced" : "Temaval är tvingande",
    "Could not set the app order" : "Det gick inte att ställa in appordningen",
    "Could not reset the app order" : "Kunde inte återställa appordningen",
    "Navigation bar settings" : "Inställningar för navigeringsfältet",
    "You can configure the app order used for the navigation bar. The first entry will be the default app, opened after login or when clicking on the logo." : "Du kan konfigurera appordningen som används för navigeringsfältet. Den första posten kommer att vara standardappen, som öppnas efter inloggning eller när du klickar på logotypen.",
    "The default app can not be changed because it was configured by the administrator." : "Standardappen kan inte ändras eftersom den konfigurerades av administratören.",
    "The app order was changed, to see it in action you have to reload the page." : "Appordningen ändrades, för att se den måste du ladda om sidan.",
    "Reset default app order" : "Återställ standardappordningen",
    "Could not set primary color" : "Kunde inte ange primär färg",
    "Reset primary color" : "Återställ primär färg",
    "Could not set global default apps" : "Det gick inte att ställa in globala standardappar",
    "Default app" : "Standardapp",
    "The default app is the app that is e.g. opened after login or when the logo in the menu is clicked." : "Standardappen är den app som är t.ex. öppnas efter inloggning eller när logotypen i menyn klickas.",
    "Use custom default app" : "Använd anpassad standardapp",
    "Global default app" : "Global standardapp",
    "Global default apps" : "Globala standardappar",
    "Default app priority" : "Prioritet för standardappar",
    "If an app is not enabled for a user, the next app with lower priority is used." : "Om en app inte är aktiverad för en användare används nästa app med lägre prioritet.",
    "Select a custom color" : "Välj en anpassad färg",
    "Reset to default" : "Återställ till grundinställningar",
    "Upload" : "Ladda upp",
    "Remove background image" : "Ta bort bakgrundsbild",
    "Universal access is very important to us. We follow web standards and check to make everything usable also without mouse, and assistive software such as screenreaders. We aim to be compliant with the {guidelines}Web Content Accessibility Guidelines{linkend} 2.1 on AA level, with the high contrast theme even on AAA level." : "Allmän åtkomst är mycket viktig för oss. Vi följer webbstandarder och kontrollerar att allt är användbart även utan mus och hjälpmedel som skärmläsare. Vi strävar efter att följa {guidelines}Web Content Accessibility Guidelines{linkend} 2.1 på AA-nivå, med temat hög kontrast även på AAA-nivå."
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-32.0.6-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/theming/l10n/sv.js <==
OC.L10N.register(
    "theming",
    {
    "The given name is too long" : "Det angivna namnet är för långt",
    "The given web address is too long" : "Den angivna adressen är för lång",
    "The given web address is not a valid URL" : "Den angivna webbadressen är inte en giltig webbadress",
    "The given legal notice address is too long" : "Den angivna juridiska notisadressen är för lång",
    "The given legal notice address is not a valid URL" : "Den angivna juridiska notisadressen är inte en giltig webbadress",
    "The given privacy policy address is too long" : "Den angivna sekretesspolicyadressen är för lång",
    "The given privacy policy address is not a valid URL" : "Den angivna sekretesspolicyadressen är inte en giltig webbadress",
    "The given slogan is too long" : "Den angivna slogan är för lång",
    "The given color is invalid" : "Den angivna färgen är inte tillgänglig",
    "%1$s should be true or false" : "%1$s skall vara sant eller falskt",
    "%1$s can only be set to %2$s through the API" : "%1$s kan endast sättas till %2$s via API.",
    "Invalid setting key" : "Ogiltig inställningsnyckel",
    "Saved" : "Sparat",
    "Invalid app given" : "Ogiltig app angiven",
    "Invalid type for setting \"defaultApp\" given" : "Ogiltig typ för inställning av \"defaultApp\" angiven",
    "The file was uploaded" : "Filen laddades upp",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "Uppladdningsfilen är för stor (upload_max_filesize i php.ini)",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Den uppladdade filen överstiger MAX_FILE_SIZE-instruktionen specificerad i HTML-form",
    "The file was only partially uploaded" : "Filen var endast delvis uppladdad",
    "No file was uploaded" : "Ingen fil laddades upp",
    "Missing a temporary folder" : "Saknar en temporär mapp",
    "Could not write file to disk" : "Kunde inte skriva fil till disk",
    "A PHP extension stopped the file upload" : "Ett PHP-tillägg stoppade filuppladdning",
    "No file uploaded" : "Ingen fil uppladdad",
    "You are already using a custom theme. Theming app settings might be overwritten by that." : "Du använder redan ett anpassat tema. Dessa appinställningar kan skrivas över.",
    "Theming" : "Teman",
    "Appearance and accessibility" : "Utseende och tillgänglighet",
    "PHP Imagick module" : "PHP Imagick modul",
    "The PHP module \"imagick\" is not enabled although the theming app is. For favicon generation to work correctly, you need to install and enable this module." : "PHP-modulen \"imagick\" är inte aktiverad trots att tema appen är det. För att favicon generering ska fungera korrekt måste du installera och aktivera den här modulen.",
    "The PHP module \"imagick\" in this instance has no SVG support. For better compatibility it is recommended to install it." : "PHP-modulen \"imagick\" har i det här fallet inget SVG-stöd. För bättre kompatibilitet rekommenderas att installera den.",
    "Dark theme with high contrast mode" : "Mörkt tema med högkontrastläge",
    "Enable dark high contrast mode" : "Aktivera mörkt högkontrastläge",
    "Similar to the high contrast mode, but with dark colours." : "Liknar högkontrastläget, men med mörka färger.",
    "Dark theme" : "Mörkt tema",
    "Enable dark theme" : "Aktivera mörkt tema",
    "A dark theme to ease your eyes by reducing the overall luminosity and brightness." : "Ett mörkt tema som underlättar för dina ögon genom att minska den totala ljusstyrkan.",
    "System default theme" : "Systemets standardtema",
    "Enable the system default" : "Aktivera systemets standard",
    "Using the default system appearance." : "Använder systemets standardutseende.",
    "Dyslexia font" : "Teckensnitt för dyslektiker",
    "Enable dyslexia font" : "Aktivera teckensnitt för dyslektiker",
    "OpenDyslexic is a free typeface/font designed to mitigate some of the common reading errors caused by dyslexia." : "OpenDyslexic är ett fritt teckensnitt/font som är utformat för att mildra några av de vanligaste lässvårigheterna som orsakas av dyslexi.",
    "High contrast mode" : "Läge med hög kontrast",
    "Enable high contrast mode" : "Aktivera läge med hög kontrast",
    "A high contrast mode to ease your navigation. Visual quality will be reduced but clarity will be increased." : "Ett läge med hög kontrast för att underlätta din navigering. Visuell kvalitet kommer att minska men tydligheten ökar.",
    "Light theme" : "Ljust tema",
    "Enable the default light theme" : "Aktivera ljust standardtema",
    "The default light appearance." : "Standardutseende för ljust tema.",
    "Legal notice" : "Rättsligt meddelande",
    "Privacy policy" : "Integritetspolicy",
    "Adjust the Nextcloud theme" : "Justera Nextcloud-tema",
    "Could not set global default apps" : "Det gick inte att ställa in globala standardappar",
    "Navigation bar settings" : "Inställningar för navigeringsfältet",
    "Default app" : "Standardapp",
    "The default app is the app that is e.g. opened after login or when the logo in the menu is clicked." : "Standardappen är den app som är t.ex. öppnas efter inloggning eller när logotypen i menyn klickas.",
    "Use custom default app" : "Använd anpassad standardapp",
    "Global default app" : "Global standardapp",
    "Global default apps" : "Globala standardappar",
    "Default app priority" : "Prioritet för standardappar",
    "If an app is not enabled for a user, the next app with lower priority is used." : "Om en app inte är aktiverad för en användare används nästa app med lägre prioritet.",
    "Theming makes it possible to easily customize the look and feel of your instance and supported clients. This will be visible for all users." : "Teman gör det möjligt att enkelt skräddarsy utseendet på ditt moln. Detta kommer att synas för alla användare.",
    "Name" : "Namn",
    "Web link" : "Webblänk",
    "Slogan" : "Slogan",
    "a safe home for all your data" : "ett säkert hem för all din data",
    "Legal notice link" : "Länk rättsligt meddelande",
    "Privacy policy link" : "Länk integritetspolicy",
    "Background and color" : "Bakgrund och färg",
    "Primary color" : "Primär färg",
    "Set the default primary color, used to highlight important elements." : "Ställ in primärfärgen, som används för att markera viktiga element.",
    "The color used for elements such as primary buttons might differ a bit as it gets adjusted to fulfill accessibility requirements." : "Färgen som används för element som primära knappar kan variera något allt eftersom den justeras för att uppfylla tillgänglighetskraven.",
    "Background color" : "Bakgrundsfärg",
    "When no background image is set the background color will be used." : "När ingen bakgrundsbild är vald kommer bakgrundsfärgen att användas.",
    "Otherwise the background color is by default generated from the background image, but can be adjusted to fine tune the color of the navigation icons." : "Annars genereras bakgrundsfärgen som standard från bakgrundsbilden, men kan justeras för att finjustera färgen på navigeringsikonerna.",
    "Use a plain background color instead of a background image." : "Använd en bakgrundsfärg istället för en bakgrundsbild.",
    "Remove background image" : "Ta bort bakgrundsbild",
    "Background image" : "Bakgrundsbild",
    "Favicon" : "Favicon",
    "Logo" : "Logotyp",
    "Navigation bar logo" : "Navigeringsfältets logo",
    "Although you can select and customize your instance, users can change their background and colors. If you want to enforce your customization, you can toggle this on." : "Även om du kan välja och anpassa din instans kan användare ändra sin bakgrund och färger. Om du vill genomdriva din anpassning kan du aktivera detta.",
    "Disable user theming" : "Inaktivera teman för användare",
    "Current selected app: {app}, position {position} of {total}" : "Aktuell vald app: {app}, position {position} av {total}",
    "Navigation bar app order" : "Navigeringsfältets app-ordning",
    "Move up" : "Flytta upp",
    "Move down" : "Flytta ner",
    "Theme selection is enforced" : "Temaval är låst",
    "Could not set the app order" : "Det gick inte att ställa in appordningen",
    "Could not reset the app order" : "Kunde inte återställa appordningen",
    "You can configure the app order used for the navigation bar. The first entry will be the default app, opened after login or when clicking on the logo." : "Du kan konfigurera appordningen som används för navigeringsfältet. Den första posten kommer att vara standardappen, som öppnas efter inloggning eller när du klickar på logotypen.",
    "The default app can not be changed because it was configured by the administrator." : "Standardappen kan inte ändras eftersom den konfigurerades av administratören.",
    "The app order was changed, to see it in action you have to reload the page." : "Appordningen ändrades, för att se den måste du ladda om sidan.",
    "Reset default app order" : "Återställ standardappordningen",
    "Select a background from your files" : "Välj en bakgrund från dina filer",
    "Select background" : "Välj bakgrund",
    "The background can be set to an image from the default set, a custom uploaded image, or a plain color." : "Bakgrunden kan ställas in till en bild från standarduppsättningen, en anpassad uppladdad bild eller en enkel färg.",
    "Custom background" : "Anpassad bakgrund",
    "Plain background" : "Enkel bakgrund",
    "Default background" : "Standardbakgrund",
    "Default shipped background images" : "Bakgrundsbilder som levereras som standard",
    "Keyboard shortcuts" : "Tangentbordsgenvägar",
    "In some cases keyboard shortcuts can interfere with accessibility tools. In order to allow focusing on your tool correctly you can disable all keyboard shortcuts here. This will also disable all available shortcuts in apps." : "I vissa fall kan tangentbordsgenvägar störa tillgänglighetsverktyg. För att kunna fokusera på ditt verktyg korrekt kan du inaktivera alla tangentbordsgenvägar här. Detta kommer också att inaktivera alla tillgängliga genvägar i appar.",
    "Disable all keyboard shortcuts" : "Inaktivera alla tangentbordsgenvägar",
    "Could not set primary color" : "Kunde inte ange primär färg",
    "Set a primary color to highlight important elements. The color used for elements such as primary buttons might differ a bit as it gets adjusted to fulfill accessibility requirements." : "Ange en primärfärg för att markera viktiga element. Färgen som används för element som primära knappar kan variera något allt eftersom den justeras för att uppfylla tillgänglighetskraven.",
    "Reset primary color" : "Återställ primär färg",
    "Reset to default" : "Återställ till grundinställningar",
    "Non image file selected" : "Vald fil är inte en bildfil",
    "Preview of the selected image" : "Förhandsgranskning av den valda bilden",
    "Universal access is very important to us. We follow web standards and check to make everything usable also without mouse, and assistive software such as screenreaders. We aim to be compliant with the {linkstart}Web Content Accessibility Guidelines{linkend} 2.1 on AA level, with the high contrast theme even on AAA level." : "Tillgänglighet är mycket viktig för oss. Vi följer webbstandarder och kontrollerar att allt är användbart även utan mus och hjälpmedel som skärmläsare. Vi strävar efter att följa {linkstart}Web Content Accessibility Guidelines{linkend} 2.1 på AA-nivå, med högkontrast-temat även på AAA-nivå.",
    "If you find any issues, do not hesitate to report them on {issuetracker}our issue tracker{linkend}. And if you want to get involved, come join {designteam}our design team{linkend}!" : "Om du hittar några problem, tveka inte att rapportera dem på {issuetracker}vår problemhanterare{linkend}. Och om du vill engagera dig, gå med i {designteam}vårt designteam{linkend}!",
    "Unable to apply the setting." : "Det gick inte att tillämpa inställningen.",
    "Appearance and accessibility settings" : "Utseende och tillgänglighetsinställningar",
    "Misc accessibility options" : "Diverse tillgänglighetsalternativ",
    "Enable blur background filter (may increase GPU load)" : "Aktivera filter för oskärpa i bakgrunden (kan öka GPU-belastningen).",
    "Customization has been disabled by your administrator" : "Anpassning har inaktiverats av din administratör",
    "Disable-user-theming should be true or false" : "Inaktivera teman för användare ska vara sant eller falskt",
    "The primary color is used for highlighting elements like important buttons. It might get slightly adjusted depending on the current color schema." : "Primärfärgen används för att markera element som viktiga knappar. Den kan komma att justeras något beroende på det aktuella färgschemat.",
    "Header logo" : "Huvud-logga",
    "Upload new header logo" : "Ladda upp ny huvud-logga",
    "Upload new favicon" : "Ladda upp nya favicon",
    "User settings" : "Användarinställningar",
    "Instead of a background image you can also configure a plain background color. If you use a background image changing this color will influence the color of the app menu icons." : "Istället för en bakgrundsbild kan du konfigurera en vanlig bakgrundsfärg. Om du använder en bakgrundsbild kommer ändring av denna färg att påverka färgen på appens menyikoner.",
    "Upload new logo" : "Ladda upp ny logotyp",
    "Upload new background and login image" : "Ladda upp ny bakgrund och inloggningsbild",
    "Background and login image" : "Bakgrund och inloggningsbild",
    "Advanced options" : "Avancerade inställningar",
    "Install the ImageMagick PHP extension with support for SVG images to automatically generate favicons based on the uploaded logo and color." : "Installera Imagemagick PHP-tillägget med stöd för SVG-bilder för att automatiskt generera favicons baserat på den uppladdade logotypen och färgen.",
    "Universal access is very important to us. We follow web standards and check to make everything usable also without mouse, and assistive software such as screenreaders. We aim to be compliant with the {guidelines}Web Content Accessibility Guidelines{linkend} 2.1 on AA level, with the high contrast theme even on AAA level." : "Allmän åtkomst är mycket viktig för oss. Vi följer webbstandarder och kontrollerar att allt är användbart även utan mus och hjälpmedel som skärmläsare. Vi strävar efter att följa {guidelines}Web Content Accessibility Guidelines{linkend} 2.1 på AA-nivå, med temat hög kontrast även på AAA-nivå.",
    ". Unable to apply the setting." : ". Det gick inte att tillämpa inställningen.",
    "No background has been selected" : "Ingen bakgrund har valts",
    "Select a custom color" : "Välj en anpassad färg",
    "Upload" : "Ladda upp"
},
"nplurals=2; plural=(n != 1);");
